@@ -29,6 +29,8 @@ sub new {
     $self->{'config'} = App::GUI::Harmonograph::Config->new();
     Wx::ToolTip::Enable( $self->{'config'}->get_value('tips') );
     Wx::InitAllImageHandlers();
+    $self->{'saved'} = 0;
+    $self->{'title'} = $title;
 
     # create GUI parts
     $self->{'tabs'}             = Wx::AuiNotebook->new($self, -1, [-1,-1], [-1,-1], &Wx::wxAUI_NB_TOP );
@@ -63,12 +65,10 @@ sub new {
     $self->{'progress'}            = App::GUI::Harmonograph::Widget::ProgressBar->new( $self, 450,  10, { red => 20, green => 20, blue => 110 });
     $self->{'board'}               = App::GUI::Harmonograph::Frame::Part::Board->new( $self , 600, 600 );
     $self->{'dialog'}{'about'}     = App::GUI::Harmonograph::Dialog::About->new();
-    $self->{'dialog'}{'interface'} = App::GUI::Harmonograph::Dialog::Interface->new();
-    $self->{'dialog'}{'function'}  = App::GUI::Harmonograph::Dialog::Function->new();
 
     my $btnw = 50; my $btnh     = 40;# button width and height
-    $self->{'btn'}{'dir'}       = Wx::Button->new( $self, -1, 'Dir',   [-1,-1],[$btnw, $btnh] );
-    $self->{'btn'}{'write_next'}= Wx::Button->new( $self, -1, 'INI',   [-1,-1],[$btnw, $btnh] );
+    $self->{'btn'}{'dir'}       = Wx::Button->new( $self, -1, 'Di&r',   [-1,-1],[$btnw, $btnh] );
+    $self->{'btn'}{'write_next'}= Wx::Button->new( $self, -1, '&INI',   [-1,-1],[$btnw, $btnh] );
     $self->{'btn'}{'draw'}      = Wx::Button->new( $self, -1, '&Draw', [-1,-1],[$btnw, $btnh] );
     $self->{'btn'}{'save_next'} = Wx::Button->new( $self, -1, '&Save', [-1,-1],[$btnw, $btnh] );
     $self->{'txt'}{'file_bdir'} = Wx::TextCtrl->new( $self,-1, $self->{'config'}->get_value('file_base_dir'), [-1,-1],  [170, -1] );
@@ -89,7 +89,6 @@ sub new {
     Wx::Event::EVT_BUTTON( $self, $self->{'btn'}{'dir'},  sub { $self->change_base_dir }) ;
     Wx::Event::EVT_BUTTON( $self, $self->{'btn'}{'write_next'},  sub {
         my $data = get_data( $self );
-        $self->inc_base_counter unless App::GUI::Harmonograph::Settings::are_equal( $self->{'last_file_settings'}, $data );
         my $path = $self->base_path . '.ini';
         $self->write_settings_file( $path);
         $self->{'config'}->add_setting_file( $path );
@@ -97,7 +96,6 @@ sub new {
     });
     Wx::Event::EVT_BUTTON( $self, $self->{'btn'}{'save_next'},  sub {
         my $data = get_data( $self );
-        $self->inc_base_counter unless App::GUI::Harmonograph::Settings::are_equal( $self->{'last_file_settings'}, $data );
         my $path = $self->base_path . '.' . $self->{'config'}->get_value('file_base_ending');
         $self->write_image( $path );
         $self->{'last_file_settings'} = $data;
@@ -122,7 +120,7 @@ sub new {
             } else { delete $all_color->{$name} }
         }
         $self->{'config'}->save();
-        $self->{'dialog'}{$_}->Destroy() for qw/interface function about/;
+        $self->{'dialog'}{'about'}->Destroy();
         $_[1]->Skip(1)
     });
 
@@ -292,6 +290,7 @@ sub init {
     $self->{'progress'}->set_color( { red => 20, green => 20, blue => 110 } );
     $self->sketch( );
     $self->SetStatusText( "all settings are set to default", 1);
+    $self->{'saved'} = 0;
 }
 
 sub get_data {
@@ -395,6 +394,11 @@ sub sketch {
     $self->{'board'}->set_sketch_flag( );
     $self->{'board'}->Refresh;
     $self->SetStatusText( "done sketching a preview", 0 );
+    if ($self->{'saved'}){
+        $self->SetTitle($self->{'title'}.'*');
+        $self->inc_base_counter();
+        $self->{'saved'} = 0;
+    }
 }
 
 sub update_base_name {
@@ -406,7 +410,7 @@ sub update_base_name {
 }
 
 sub inc_base_counter {
-    my ($self) = @_;
+    my ($self, $type) = @_;
     my $dir = $self->{'config'}->get_value('file_base_dir');
     $dir = App::GUI::Harmonograph::Settings::expand_path( $dir );
     my $base = File::Spec->catfile( $dir, $self->{'config'}->get_value('file_base_name') );
@@ -471,6 +475,8 @@ sub write_settings_file {
         $self->update_recent_settings_menu();
         $self->SetStatusText( "saved settings into file $file", 1 );
     }
+    $self->{'saved'} = 1;
+    $self->SetTitle( $self->{'title'} );
 }
 
 sub update_recent_settings_menu {
@@ -495,6 +501,8 @@ sub write_image {
     $self->{'board'}->save_file( $file );
     $file = App::GUI::Harmonograph::Settings::shrink_path( $file );
     $self->SetStatusText( "saved image under: $file", 0 );
+    $self->{'saved'} = 1;
+    $self->SetTitle($self->{'title'});
 }
 
 1;
